@@ -95,29 +95,30 @@ class KeycloakMiddleware(KeycloakMiddlewareMixin, MiddlewareMixin):
         To be executed before the view each request
         """
         # Checks URIs that doesn't need authentication
-        if self.pass_auth(request) or self.is_graphql_endpoint(request):
-            return self.get_response(request)
+        # if self.pass_auth(request) or self.is_graphql_endpoint(request):
+        #     return self.get_response(request)
 
-        if self.is_auth_header_missing(request):
-            return JsonResponse(
-                {"detail": "Authentication credentials were not provided."},
-                status=401,
-            )
+        # if self.is_auth_header_missing(request):
+        #     return JsonResponse(
+        #         {"detail": "Authentication credentials were not provided."},
+        #         status=401,
+        #     )
 
-        token = self.get_token(request)
-        if token is None:
-            return JsonResponse(
-                {"detail": "Invalid token structure. Must be 'Bearer <token>'"},
-                status=401,
-            )
+        if not self.is_auth_header_missing(request):
+            token = self.get_token(request)
+            if token is None:
+                return JsonResponse(
+                    {"detail": "Invalid token structure. Must be 'Bearer <token>'"},
+                    status=401,
+                )
 
-        if not self.keycloak.is_token_active(token):
-            return JsonResponse(
-                {"detail": "Invalid or expired token."},
-                status=401,
-            )
+            if not self.keycloak.is_token_active(token):
+                return JsonResponse(
+                    {"detail": "Invalid or expired token."},
+                    status=401,
+                )
 
-        request = self.append_user_info_to_request(request, token)
+            request = self.append_user_info_to_request(request, token)
         return self.get_response(request)
 
     def pass_auth(self, request):
